@@ -15,7 +15,7 @@ def main():
     print 'Listening for messages'
     try:
         while True:
-            (session_id, message_type, data) = in_socket.recv_multipart()
+            (message_type, session_id, data) = in_socket.recv_multipart()
 
             if message_type == 'connect':
                 print "{} connected".format(session_id)
